/*********************************************************************
   Copyright 2005 Danny Goodman (www.dannyg.com). 
   Example .js file from the book:
   "Mac OS X Technology Guide to Dashboard"
   Published by SpiderWorks (spiderworks.com)
   
   You may use or all of the code in this example file for your own
   widgets, but you must include the above attribution and copyright
   notice in the source code of widgets you distribute or make 
   available to others. Redistribution of this widget requires
   advance permission from the author.
   
***********************************************************************/
// fader object constructor
function fader() {
	this.timer = null;    // setTimeout timer
	this.increment = 0;   // opacity steps
	this.currOpacity = 0; // current setting
	this.boundary = 0;    // max or min value
	this.iShown = false;  // flag for being visible
}

// show the "i" Info icon (via fade-in)
function showi(evt) {
	var elemID = "flip";  // the "i" icon
	var elem = document.getElementById(elemID);
	if (!elem.fader || !elem.fader.iShown) {
		if (elem.fader && elem.fader.timer != null) {
			clearTimeout(elem.fader.timer);
			elem.fader.timer = null;
		}
		elem.fader = new fader();
		elem.fader.boundary = 1;
		elem.fader.increment = 0.2;
		doFade(elemID);
		elem.fader.iShown = true;
	}
}

// hide the "i" Info icon (via fade-out)
function hidei(evt) {
	var elemID = "flip";  // the "i" icon
	var elem = document.getElementById(elemID);
	if (elem.fader.iShown && 
		evt.relatedTarget.tagName == "HTML") {
		if (elem.fader.timer != null) {
			clearTimeout(elem.fader.timer);
			elem.fader.timer = null;
		}
		elem.fader.boundary = 0;
		elem.fader.increment = -0.2;
		doFade(elemID);
		elem.fader.iShown = false;
	}
}

// fade element in or out based on fader properties
function doFade(elemID) {
	var elem = document.getElementById(elemID);

	if (elem.fader.currOpacity == elem.fader.boundary) {
		clearTimeout(elem.fader.timer);
	} else {
		elem.fader.currOpacity = 
			parseFloat((elem.fader.currOpacity +			
			elem.fader.increment).toFixed(1));
		elem.style.opacity = elem.fader.currOpacity;
		elem.fader.timer = setTimeout("doFade('" + 
			elemID + "')", 100);
	}
}

// show and hide "rollie" circles behind "i"
function showRollie(evt) {
	document.getElementById("fliprollie").style.display = "block";
}

function hideRollie(evt) {
	document.getElementById("fliprollie").style.display = "none";
}

// flip around to back side
function toBack(evt) {
	var front = document.getElementById("front");
	var back = document.getElementById("back");
		
	// lock widget refreshing momentarily
	if (window.widget) {
		widget.prepareForTransition("ToBack");
	}

	window.resizeTo(377, 332);
	
	// swap display styles
	front.style.display = "none";
	back.style.display = "block";
	
	// now that back is displayed,
	// finish centering "Done" button
	// if needed (only once)
	var doneBtn = 
		document.getElementById("doneButton");
	if (doneBtn.needsCentering) {
		doneBtn.style.left = doneBtn.offsetLeft - 
			Math.round(doneBtn.offsetWidth/2);
		doneBtn.needsCentering = false;
	}
	// do the flip!
	if (window.widget) {
		setTimeout ("widget.performTransition()", 0);		
	}
	// hide rollie in prep for return to front
	document.getElementById("fliprollie").style.display = "none";

}

// flip around to front
function toFront(evt) {
	reload();
	
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget) {
		widget.prepareForTransition("ToFront");
	}
	
	front.style.display = "block";
	back.style.display = "none";
	if (window.widget) {
		setTimeout ("widget.performTransition()", 0);		
	}
	setPreferences();
}

var keyNames = ["total","exile","npc","koppi","congrats"];


function getPreferences() {
	if (window.widget && typeof widget.preferenceForKey(getPrefKey("total")) != "undefined") {
		for (var i = 0; i < keyNames.length; i++) {
			document.getElementById(keyNames[i]).value = widget.preferenceForKey(getPrefKey(keyNames[i]));
		}
		if (widget.preferenceForKey('alertMe')=='checked') {
			document.getElementById('alertMe').checked = true;
		} else {
			document.getElementById('alertMe').checked = false;
		}

	}
}

function setPreferences() {
	if (window.widget) {
		for (var i = 0; i < keyNames.length; i++) {
			widget.setPreferenceForKey(document.getElementById(keyNames[i]).value, getPrefKey(keyNames[i]));
		}
		if (document.getElementById('alertMe').checked==true) {
			widget.setPreferenceForKey('checked', 'alertMe');
		} else {
			widget.setPreferenceForKey('unchecked', 'alertMe');
		}
	}
}

function clearPreferences() {
	if (window.widget) {
		for (var i = 0; i < keyNames.length; i++) {
			widget.setPreferenceForKey(null, getPrefKey(keyNames[i]));
		}
	}
}

// generate preference key tied to this widget instance
function getPrefKey(label) {
	if (window.widget) {
		//return widget.identifier + "-" + label;
		return label;
	}
}

// invoked by <body>'s onload event handler
function init() {
	var doneBtn = document.getElementById("doneButton");
	// set flag to allow centering once it's displayed
	doneBtn.needsCentering = true;
	// let WidgetResources script create button
	getPreferences();  // read preferences
	createGenericButton(doneBtn, "Done", toFront);
	
}

// quickly flicker rollie to force
// clean redraw of resized widget
function forceRedraw() {
       startpos = document.getElementById('frontTop').scrollHeight + document.getElementById('frontBody').scrollHeight-3;
       document.getElementById('frontBottom').style.top = startpos+'px';
       
       if (window.outerHeight != startpos + document.getElementById('frontBottom').scrollHeight) {
       		growby = startpos + document.getElementById('frontBottom').scrollHeight - window.outerHeight;
       		window.resizeBy(0, growby);

       }
	setTimeout("showRollie()", 0);
	setTimeout("hideRollie()", 0);


}